@@ -8,8 +8,8 @@ from importlib import metadata
 import logging
 logger = logging.getLogger('millconnect.gui')
 
-from PyQt6.QtCore import QTimer ,QRunnable, QThreadPool, pyqtSlot, pyqtSignal, QTranslator, QDir, QStandardPaths
-from PyQt6.QtWidgets import QApplication, QLabel, QWidget, QVBoxLayout, QProgressBar, QStackedWidget, QFileDialog
+from PyQt6.QtCore import QTimer ,QRunnable, QThreadPool, pyqtSlot, pyqtSignal, QTranslator, QDir, QStandardPaths, Qt
+from PyQt6.QtWidgets import QApplication, QLabel, QWidget, QVBoxLayout, QProgressBar, QStackedWidget, QFileDialog, QPushButton
 from PyQt6.QtGui import QIcon
 
 from .project import Project
@@ -124,6 +124,7 @@ class WebsocketServer(QRunnable):
 
 class BrowserDialog(QWidget):
     uploadFinished = pyqtSignal()
+    uploadFailed = pyqtSignal()
 
     def __init__(self, parent=None, *args, **kwargs):
         super().__init__(parent, *args, **kwargs)
@@ -143,10 +144,34 @@ class BrowserDialog(QWidget):
         self.worker = WebsocketServer(lambda websocket: handleConnection(websocket, project, apiHost, self))
         self.threadpool.start(self.worker)
 
-    def closeWebsocketServer(self):
+    def closeWebsocketServer(self, success=True):
         if self.worker:
             self.worker.stopServer()
-        self.uploadFinished.emit()
+        if success:
+            self.uploadFinished.emit()
+        else:
+            self.uploadFailed.emit()
+
+class ErrorDialog(QWidget):
+    buttonPressed = pyqtSignal()
+
+    def __init__(self, parent=None, *args, **kwargs):
+        super().__init__(parent, *args, **kwargs)
+
+        layout = QVBoxLayout()
+        self.setLayout(layout)
+
+        self.label = QLabel(self, text=self.tr('An Error occurt during uploading of the project. Please contact the support.'))
+        layout.addWidget(self.label)
+
+        self.button = QPushButton(self.tr('OK'), self)
+        layout.addWidget(self.button)
+
+        self.button.clicked.connect(self.handleButtonPressed)
+
+    @pyqtSlot()
+    def handleButtonPressed(self):
+        self.buttonPressed.emit()
 
 class MainWindow(QWidget):
     def __init__(self, parent=None, projectPath: Path=None, host: str=None, uploadURL: str=None, no_update: bool=False, *args, **kwargs):
@@ -175,7 +200,11 @@ class MainWindow(QWidget):
         self.projectSelector = ProjectSelector(self)
         self.stackedWidget.addWidget(self.projectSelector)
 
+        self.errorDialog = ErrorDialog(self)
+        self.stackedWidget.addWidget(self.errorDialog)
+
         self.updatingDialog.restartSignal.connect(self.close)
+        self.errorDialog.buttonPressed.connect(self.close)
 
         if self.projectPath:
             self.updatingDialog.noUpdateSignal.connect(self.showBrowserDialog)
@@ -186,6 +215,7 @@ class MainWindow(QWidget):
             self.projectSelector.folderSelected.connect(self.setProjectPath)
 
         self.browserDialog.uploadFinished.connect(self.close)
+        self.browserDialog.uploadFailed.connect(self.showErrorDialog)
 
         if no_update:
             if self.projectPath:
@@ -222,20 +252,40 @@ class MainWindow(QWidget):
         self.showBrowserDialog()
         self.startWebsocket()
 
+    @pyqtSlot()
+    def showErrorDialog(self):
+        self.stackedWidget.setCurrentWidget(self.errorDialog)
+        self.update()
+        self.setWindowState( (self.windowState() & ~Qt.WindowState.WindowMinimized) | Qt.WindowState.WindowActive)
+        self.raise_()  # for MacOS
+        self.activateWindow() # for Windows
+
     def closeEvent(self, event):
         self.browserDialog.closeWebsocketServer()
         return super().closeEvent(event)
 
 def main():
-    logging.basicConfig(stream=sys.stdout, level=logging.DEBUG, format='%(asctime)s %(name)s %(levelname)s: %(message)s')
-
     parser = argparse.ArgumentParser(description='millConnect order creator.')
     parser.add_argument('projectPath', nargs='?', type=Path, default=None, help='The path to a project folder.')
     parser.add_argument('--host', nargs='?', type=str, default='https://api.connect.millhouse.de/v1', help='The URL of the api, default: https://api.connect.millhouse.de/v1')
     parser.add_argument('--uploadURL', nargs='?', type=str, default='https://connect.millhouse.de/uploadOrder', help='The URL to open in the browser, default: https://connect.millhouse.de/uploadOrder')
     parser.add_argument('--no-update', action='store_true', help='Do not check for updates.')
+    parser.add_argument('-v','--verbose', action='store_true', help='Verbose logging.')
     args = parser.parse_args()
 
+    logFormatter = logging.Formatter('%(asctime)s %(name)s %(levelname)s: %(message)s')
+
+    fileHandler = logging.FileHandler("millconnect-client.log", mode='w')
+    fileHandler.setFormatter(logFormatter)
+
+    consoleHandler = logging.StreamHandler()
+    consoleHandler.setFormatter(logFormatter)
+
+    logLevel = logging.DEBUG if args.verbose else logging.INFO
+    logger.setLevel(logLevel)
+
+    logging.basicConfig(level=logLevel, handlers=[fileHandler, consoleHandler])
+
     app = QApplication(sys.argv)
     app.setOrganizationName('millhouse GmbH')
     app.setApplicationName('millCONNECT Client')
