@@ -161,7 +161,9 @@ class Project(object):
                 element['teeth'].append({
                     'id': None,
                     'fdi': tooth.fdi,
-                    'type': tooth.type
+                    'type': tooth.type,
+                    'implant_type': tooth.implant_type,
+                    'implant_system': tooth.implant_system
                 })
 
         for cadModel in cadOrder.models:
@@ -186,7 +188,6 @@ class Project(object):
                 })
 
         return order
-
     
     def update(self, modifiedOrder: dict) -> None:
         order = {
@@ -218,7 +219,9 @@ class Project(object):
                 element['teeth'].append({
                     'id': None,
                     'fdi': tooth['fdi'],
-                    'type': tooth['type']
+                    'type': tooth['type'],
+                    'implant_type': tooth['implant_type'],
+                    'implant_system': tooth['implant_system']
                 })
         
         self.order = order
